Using several accounts — Poezio 0.9-dev documentation

# Using several accounts

Poezio does not support multi-accounts, and we do not plan to do so in a foreseeable future. However, you can run several poezio instances (e.g. with tmux or screen) to have similar functionnality.

You can specify a different configuration file than the default with:

    ./launch.sh -f separate_config.cfg

The relevant options for a separate config are the following:

- plugins_dir: A different directory for the plugin sources (not _that_ useful)
- log_dir: A different directory for logs
- plugins_conf_dir: A different directory for plugin configurations ; useful for the GPG plugin, for example.

Those options are detailed in the configuration page.